![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)
![](https://anaconda.org/andrazpolak/atpthings/badges/version.svg)
[![PyPI](https://badge.fury.io/py/atpthings.svg)](https://badge.fury.io/py/atpthings)

# ATP-things

Homepage: https://atp-things.github.io/
Repository: https://github.com/atp-things/pkg-python-util

## PYPI

URL: https://pypi.org/project/atpthings/

### Install

```bash
pip install atpthings
```

## Conda

URL: https://anaconda.org/andrazpolak/atpthings

### Install

```bash
conda install -c andrazpolak atpthings
```

## Import

```python
import atpthings
```
